#!/usr/bin/env ruby

# frozen_string_literal: true

require 'bundler/setup'
require 'dry/cli'

require_relative 'cmd/cpu'

module PCHWBM
  module CLI
    # Commands module for dry-cli
    module Commands

      extend Dry::CLI::Registry

      # CPU subcommand definition
      module CPU
        # CPU stress test command
        class Stress < Dry::CLI::Command

          desc 'CPU tests.'

          def call(*)
            CMD.cpu_stress()
          end

        end
      end

      # Version subcommand definition
      class Version < Dry::CLI::Command

        desc 'Print program version.'

        def call(*)
          puts('PCHWBM tool version 0.1.0.')
        end

      end

      # Register commands with the CLI
      register 'version', Version, aliases: ['v', '-v', '--version']
      register 'cpu' do |prefix|
        prefix.register('stress', CPU::Stress)
      end

    end
  end
end

# Run the CLI
Dry::CLI.new(PCHWBM::CLI::Commands).call()
